<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Selim Farsakoğlu <farsakogluselim@yahoo.de>
 * @author Aydın Coşkuner <aydinweb@gmail.com>
 * @author Cihan Kahveci <kahvecicihan@gmail.com>
 * @author Yavuz Selim <yavuzselim@gmail.com>
 * @author Caleb Maclennan <caleb@alerque.com>
 * @author farukerdemoncel@gmail.com
 */
$lang['admin_acl']             = 'Erişim Kontrol Listesi (ACL) Yönetimi';
$lang['acl_group']             = 'Grup:';
$lang['acl_user']              = 'Kullanıcı:';
$lang['acl_perms']             = 'Şunun için yetkiler:';
$lang['page']                  = 'Sayfa';
$lang['namespace']             = 'Namespace';
$lang['btn_select']            = 'Seç';
$lang['p_user_id']             = '<b class="acluser">%s</b> kullanıcısının şu anda <b class="aclpage">%s</b> sayfası için yetkisi: <i>%s</i>.';
$lang['p_user_ns']             = '<b class="acluser">%s</b> kullanıcısının şu anda <b class="aclns">%s</b> namesapace\'i için yetkisi: <i>%s</i>.';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> grubunun şu anda <b class="aclpage">%s</b> sayfası için yetkisi: <i>%s</i>.';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> grubunun şu anda <b class="aclns">%s</b> namesapace\'i için yetkisi: <i>%s</i>.';
$lang['p_choose_id']           = 'Lütfen <b class="aclpage">%s</b> sayfasına izin verilen yetkilerini görmek veya değiştirmek için yukarıdaki forma <b>bir kullanıcı veya grup adı</b> girin.';
$lang['p_choose_ns']           = 'Lütfen <b class="aclpage">%s</b> namespace\'ie izin verilen yetkileri görmek veya değiştirmek için yukarıdaki forma <b>bir kullanıcı veya grup adı</b> girin.';
$lang['p_inherited']           = 'Not: Bu izinler doğrudan ayarlanmadan başka grup veya üst namespace\'lerden gelmektedir.';
$lang['p_isadmin']             = 'Not: Seçili grup veya kullanıcı, "Ana kullanıcı" olarak atandığından tüm izinlere sahiptir.';
$lang['p_include']             = 'Üst seviye izinler alt izinleri içermektedir. Oluşturma, Yükleme ve Silme yetkisi sadece namespace\'e uygulanmaktadır. Bu yetki sayfalara uygulanmaz.';
$lang['current']               = 'Şimdiki ACL(İzin Kontrol listesi) kuralları';
$lang['where']                 = 'Sayfa/Namespace';
$lang['who']                   = 'Kullanıcı/Grup';
$lang['perm']                  = 'İzinler';
$lang['acl_perm0']             = 'Yok';
$lang['acl_perm1']             = 'Okuma';
$lang['acl_perm2']             = 'Değiştirme';
$lang['acl_perm4']             = 'Oluşturma';
$lang['acl_perm8']             = 'Yükleme';
$lang['acl_perm16']            = 'Silme';
$lang['acl_new']               = 'Yeni giriş ekle';
$lang['acl_mod']               = 'Eski girişi değiştirme';
